==> haskell-x509-store-1.6.7-172-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.7
visibility:           public
id:                   x509-store-1.6.7-GjMuzyM4405JwkexKUzc5E
key:                  x509-store-1.6.7-GjMuzyM4405JwkexKUzc5E
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  0e33a0c04c3897bee5af8f23eee557cb
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-store-1.6.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-store-1.6.7
hs-libraries:         HSx509-store-1.6.7-GjMuzyM4405JwkexKUzc5E
depends:
    asn1-encoding-0.9.6-1hiEaDzNnvZCKkl9Gb4izO
    asn1-types-0.3.4-KHBfkOvXvyLC7EfnO8fkLD base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.29-19SjDRwWNox27CMfesQpq4 directory-1.3.6.1
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-KLN0tuS3ZoG84EBMFRxUqE
    x509-1.7.5-KZBg6E9cDNpzkDdONM3tO

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.7-173-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.7
visibility:           public
id:                   x509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3
key:                  x509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  b32ccad1c6b6eea9b121e745fc6a17cf
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-9.0.1/site-local/x509-store-1.6.7
library-dirs:         /usr/lib/ghc-9.0.1/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/x509-store-1.6.7
hs-libraries:         HSx509-store-1.6.7-E1M1yu7n5ys7g0MI3dEOO3
depends:
    asn1-encoding-0.9.6-GST7u8YWSVMBlxeVag7x5g
    asn1-types-0.3.4-7gCtfa0duAqTepdsDJGVJ base-4.15.0.0
    bytestring-0.10.12.1 containers-0.6.4.1
    cryptonite-0.29-GRn4QfSajtp4ejYMImOiTS directory-1.3.6.1
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-HYg3Jt06Zqq3C6bOo96L1R
    x509-1.7.5-HyBJj96t9GC2vaOmQQ4ozv

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
